==> core_models-0.1.0.gem: app/controllers/core_models/people_and_companies/business_languages_controller.rb <==
require_dependency "core_models/core_models_controller"

module CoreModels
  class PeopleAndCompanies::BusinessLanguagesController < CoreModelsController
    # GET /people_and_companies/business_languages
    # GET /people_and_companies/business_languages.json
    def index
      @people_and_companies_business_languages = PeopleAndCompanies::BusinessLanguage.all

      respond_to do |format|
        format.html # index.html.erb
        format.json { render :json => @people_and_companies_business_languages }
      end
    end

    # GET /people_and_companies/business_languages/1
    # GET /people_and_companies/business_languages/1.json
    def show
      @people_and_companies_business_language = PeopleAndCompanies::BusinessLanguage.find(params[:id])

      respond_to do |format|
        format.html # show.html.erb
        format.json { render :json => @people_and_companies_business_language }
      end
    end

    # GET /people_and_companies/business_languages/new
    # GET /people_and_companies/business_languages/new.json
    def new
      @people_and_companies_business_language = PeopleAndCompanies::BusinessLanguage.new

      respond_to do |format|
        format.html # new.html.erb
        format.json { render :json => @people_and_companies_business_language }
      end
    end

    # GET /people_and_companies/business_languages/1/edit
    def edit
      @people_and_companies_business_language = PeopleAndCompanies::BusinessLanguage.find(params[:id])
    end

    # POST /people_and_companies/business_languages
    # POST /people_and_companies/business_languages.json
    def create
      @people_and_companies_business_language = PeopleAndCompanies::BusinessLanguage.new(params[:people_and_companies_business_language])

      respond_to do |format|
        if @people_and_companies_business_language.save
          format.html { redirect_to @people_and_companies_business_language, :notice => 'Business language was successfully created.' }
          format.json { render :json => @people_and_companies_business_language, :status => :created, :location => @people_and_companies_business_language }
        else
          format.html { render :action => "new" }
          format.json { render :json => @people_and_companies_business_language.errors, :status => :unprocessable_entity }
        end
      end
    end

    # PUT /people_and_companies/business_languages/1
    # PUT /people_and_companies/business_languages/1.json
    def update
      @people_and_companies_business_language = PeopleAndCompanies::BusinessLanguage.find(params[:id])

      respond_to do |format|
        if @people_and_companies_business_language.update_attributes(params[:people_and_companies_business_language])
          format.html { redirect_to @people_and_companies_business_language, :notice => 'Business language was successfully updated.' }
          format.json { head :no_content }
        else
          format.html { render :action => "edit" }
          format.json { render :json => @people_and_companies_business_language.errors, :status => :unprocessable_entity }
        end
      end
    end

    # DELETE /people_and_companies/business_languages/1
    # DELETE /people_and_companies/business_languages/1.json
    def destroy
      @people_and_companies_business_language = PeopleAndCompanies::BusinessLanguage.find(params[:id])
      @people_and_companies_business_language.destroy

      respond_to do |format|
        format.html { redirect_to people_and_companies_business_languages_url }
        format.json { head :no_content }
      end
    end
  end
end

==> core_models-0.2.9.gem: app/controllers/core_models/people_and_companies/business_languages_controller.rb <==
require_dependency "core_models/core_models_controller"

module CoreModels
  class PeopleAndCompanies::BusinessLanguagesController < CoreModelsController
    # GET /people_and_companies/business_languages
    # GET /people_and_companies/business_languages.json
    def index
      @people_and_companies_business_languages = PeopleAndCompanies::BusinessLanguage.all

      respond_to do |format|
        format.html # index.html.erb
        format.json { render :json => @people_and_companies_business_languages }
      end
    end

    # GET /people_and_companies/business_languages/1
    # GET /people_and_companies/business_languages/1.json
    def show
      @people_and_companies_business_language = PeopleAndCompanies::BusinessLanguage.find(params[:id])

      respond_to do |format|
        format.html # show.html.erb
        format.json { render :json => @people_and_companies_business_language }
      end
    end

    # GET /people_and_companies/business_languages/new
    # GET /people_and_companies/business_languages/new.json
    def new
      @people_and_companies_business_language = PeopleAndCompanies::BusinessLanguage.new

      respond_to do |format|
        format.html # new.html.erb
        format.json { render :json => @people_and_companies_business_language }
      end
    end

    # GET /people_and_companies/business_languages/1/edit
    def edit
      @people_and_companies_business_language = PeopleAndCompanies::BusinessLanguage.find(params[:id])
    end

    # POST /people_and_companies/business_languages
    # POST /people_and_companies/business_languages.json
    def create
      @people_and_companies_business_language = PeopleAndCompanies::BusinessLanguage.new(params[:people_and_companies_business_language])

      respond_to do |format|
        if @people_and_companies_business_language.save
          format.html { redirect_to @people_and_companies_business_language, :notice => 'Business language was successfully created.' }
          format.json { render :json => @people_and_companies_business_language, :status => :created, :location => @people_and_companies_business_language }
        else
          format.html { render :action => "new" }
          format.json { render :json => @people_and_companies_business_language.errors, :status => :unprocessable_entity }
        end
      end
    end

    # PUT /people_and_companies/business_languages/1
    # PUT /people_and_companies/business_languages/1.json
    def update
      @people_and_companies_business_language = PeopleAndCompanies::BusinessLanguage.find(params[:id])

      respond_to do |format|
        if @people_and_companies_business_language.update(params[:people_and_companies_business_language])
          format.html { redirect_to @people_and_companies_business_language, :notice => 'Business language was successfully updated.' }
          format.json { head :no_content }
        else
          format.html { render :action => "edit" }
          format.json { render :json => @people_and_companies_business_language.errors, :status => :unprocessable_entity }
        end
      end
    end

    # DELETE /people_and_companies/business_languages/1
    # DELETE /people_and_companies/business_languages/1.json
    def destroy
      @people_and_companies_business_language = PeopleAndCompanies::BusinessLanguage.find(params[:id])
      @people_and_companies_business_language.destroy

      respond_to do |format|
        format.html { redirect_to people_and_companies_business_languages_url }
        format.json { head :no_content }
      end
    end
  end
end
